<?php
namespace PME\Modules\Planejamento\Parametrizacao;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class NutrientesPorProduto extends \Zeedhi\Framework\Controller\Report {
    protected $entityManager;
    protected $birtStrategy;
    protected $lista;
    protected $utilities;
    protected $environment;

    public function __construct(ReportService $reportService, $entityManager, $birtStrategy, $lista, $utilities, $connection, $environment) {
        $this->entityManager = $entityManager;
        $this->birtStrategy = $birtStrategy;
        $this->lista = $lista;
        $this->utilities = $utilities;
        $this->connection = $connection;
        $this->environment = $environment;

        parent::__construct($reportService);
    }

	protected $reportMapping = array (
        'GER04000' => 
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
              "TAMACNIVEL"  => "P_NIVEL",
              "PRODINICIAL" => "P_PRODINI",
              "PRODFINAL"   => "P_PRODFIM",
              "NUTRIENTES"  => "P_CDNUTRIENTE",
              "ORDENA"      => "P_ORDENA",
              "CDNVPRODUTO" => "P_CDNVPRODMASK",
              "PRODUCTMASK" => "P_PRODUCTMASK",
              "NRORG"       => "P_NRORG",
              "ORDEM"       => "P_CRESDECRES"
            )
        ),
        'GER04001' => 
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
              "TAMACNIVEL"  => "P_NIVEL",
              "PRODINICIAL" => "P_PRODINI",
              "PRODFINAL"   => "P_PRODFIM",
              "NUTRIENTES"  => "P_CDNUTRIENTE",
              "ORDENA"      => "P_ORDENA",
              "CDNVPRODUTO" => "P_CDNVPRODMASK",
              "PRODUCTMASK" => "P_PRODUCTMASK",
              "NRORG"       => "P_NRORG",
              "ORDEM"       => "P_CRESDECRES"
            )
        )
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $nrorg = $this->utilities->getNrOrg();
        
        if (empty($row['NUTRIENTES'])) $row['NUTRIENTES'] = 'T';
        else {
            $nutrientes = [];
            foreach ($row['NUTRIENTES'] as $pos) {
                $concatNutri = $pos['CDNUTRIENTE'];
                array_push($nutrientes, $concatNutri);
            }
            $row['NUTRIENTES'] = '_' . implode("_", $nutrientes) . '_';
        }
        
        $cdprodIni = empty($row['PRODINICIAL']['CDARVPROD']) ? 0 : $row['PRODINICIAL']['CDARVPROD'];
        if(empty($row['PRODFINAL']['CDARVPROD'])) $cdprodFin = 'zzzzzzzzzzz';
        else $cdprodFin = str_pad($row['PRODFINAL']['CDARVPROD'], 10, 'z');
        
        $row['PRODINICIAL'] = $cdprodIni;
        $row['PRODFINAL'] = $cdprodFin;
        $row['NRORG'] = $nrorg;
      
        $this->birtStrategy->setReportLocale($this->utilities->getLanguage());
        $this->birtStrategy->setReportFormat(strtolower($row['reportFormat']));
    }

    public function acrescentar(DTO\Request\Row $request, DTO\Response $response){
		$parameters = $request->getParameters();
        $rows = $parameters['checkedRows'];
        $this->procedure($rows);
	}

    public function sobrepor(DTO\Request\Row $request, DTO\Response $response){
		$parameters = $request->getParameters();
        $rows = $parameters['checkedRows'];
        $this->procedure($rows);
	}

    public function procedure($rows) {
        $nrorg = $this->environment->getNrOrg();
        $rows['LISTAPRODUTO'] = $this->lista->geraLista($rows[0]['PRODSELECIONADO'], $nrorg);

        $connection = $this->entityManager->getConnection();
		$procedure = new StoredProcedure($connection, 'EXPORTA_NUTRIENTES');
		
		$procedure->addParam(new Param('P_CDPRODORIG', Param::PARAM_INPUT, $rows[0]['PRODUTOORIGEM'],    Param::PARAM_TYPE_STR));
		$procedure->addParam(new Param('P_LISTANUTR',  Param::PARAM_INPUT, $rows[0]['NUTRIENTESCONCAT'], Param::PARAM_TYPE_STR));
		$procedure->addParam(new Param('P_LISTAPROD',  Param::PARAM_INPUT, $rows['LISTAPRODUTO'],        Param::PARAM_TYPE_STR));
		$procedure->addParam(new Param('P_OPERACAO',   Param::PARAM_INPUT, $rows[0]['OPERACAO'],         Param::PARAM_TYPE_STR));

		$procedure->execute();
    }
}